@@ -9,7 +9,6 @@ import base64
 import json
 import sys
 import argparse
-import time
 
 
 try:
@@ -88,7 +87,7 @@ class CartoDbDashboard:
 
     def import_data(self, datafile, type_guessing = 'true'):
         try:
-
+            self._log('NEW..')
             params = {
                 'type_guessing' : type_guessing
             }
@@ -112,13 +111,16 @@ class CartoDbDashboard:
                     elif d['state']=='importing':
                         self._log('Importing data...')
                     elif d['state']=='complete':
-                        complete = True
-                        self._log('Table "%s" created' % d['table_name'])
-                        return complete,d['table_name']
+                        if d['success']==True:
+                            complete = True
+                            self._log('Table "%s" created' % d['table_name'])
+                            return complete,d['table_name']
+                        else:
+                            self._error(d['get_error_text']['what_about'])
+
                 if d['state']=='failure':
                     self._error(d['get_error_text']['what_about'])
 
-
         except CartoDBDashboardException as e:
             self._log('some error occurred: %s' %(e))
             return False
@@ -172,22 +174,19 @@ class CartoDbDashboard:
 
     def get_row_count(self,table):
         try:
+            count = -1
             sql = "SELECT count(*) FROM %s" % table
-
             data = self.sql_api(sql)
-            count = data['rows'][0]['count']
+            if data:
+                if 'error' in data.keys():
+                    return count
+                count = data['rows'][0]['count']
             return count
         except CartoDBDashboardException as e:
             self._log('some error occurred: %s' %(e))
             return 0
 
-
-
     def rename_table(self, table_name, new_table_name):
-        print "Start renaming process by a little wait of 30s from %s" % time.ctime()
-        time.sleep( 60 )
-        print "Hopefully we are now good to go"
-
         try:
             if self.table_exists(table_name):
                 sql = "ALTER TABLE %s  RENAME TO %s" % (table_name, new_table_name)
@@ -204,11 +203,8 @@ class CartoDbDashboard:
 
     def table_exists(self, table_name):
         try:
-            sql =  "SELECT relname FROM pg_class WHERE relname = '%s' " % table_name
-            data = self.sql_api(sql)
-            if data['total_rows'] > 0:
-                if data['rows'][0]['relname'] == table_name:
-                    return True
+            if self.get_row_count(table_name) >=0:
+                return True
             return False
 
         except CartoDBDashboardException as e:
